@@ -111,7 +111,7 @@ namespace Oxygen
         }
 
         //* duration
-        virtual void setEnabled( bool value )
+        void setEnabled( bool value )
         {
             BaseEngine::setEnabled( value );
             _hoverData.setEnabled( value );
@@ -120,7 +120,7 @@ namespace Oxygen
         }
 
         //* duration
-        virtual void setDuration( int value )
+        void setDuration( int value )
         {
             BaseEngine::setDuration( value );
             _hoverData.setDuration( value );
@@ -131,7 +131,7 @@ namespace Oxygen
         public Q_SLOTS:
 
         //* remove widget from map
-        virtual bool unregisterWidget( QObject* object )
+        bool unregisterWidget( QObject* object )
         {
             if( !object ) return false;
             bool found = false;
